@@ -75,8 +75,8 @@ impl FileManipulator {
             }
         }
         result.sort_by_key(|path| path.metadata().unwrap().created().unwrap());
-        if result.len() >= self.max_files {
-            let surplus = result.len() - self.max_files + 1;
+        if result.len() > self.max_files {
+            let surplus = result.len() - self.max_files;
             let files_to_remove = &result[0..surplus];
             for file in files_to_remove {
                 remove_file(file.path())?;
